Convert an osmdata query of class opq to a character string query to be submitted to the overpass API.
Examples
if (FALSE) { # \dontrun{
q <- opq ("hampi india")
opq_string (q)
} # }
Convert an osmdata query of class opq to a character string query to be submitted to the overpass API.
if (FALSE) { # \dontrun{
q <- opq ("hampi india")
opq_string (q)
} # }