Learn R Programming

osmdata (version 0.3.0)

osm_multilines: Extract all osm_multilines from an osmdata_sf object

Description

id must be of an osm_points or osm_lines object (and can not be the id of an osm_polygons object because multilines by definition contain no polygons. osm_multilines returns any multiline object(s) which contain the object specified by id.

Usage

osm_multilines(dat, id)

Value

An sf Simple Features Collection of multilines

Arguments

dat

An object of class osmdata_sf

id

OSM identification of one of more objects for which multilines are to be extracted

See Also

Other search: osm_lines(), osm_multipolygons(), osm_points(), osm_polygons()

Examples

Run this code
if (FALSE) {
dat <- opq ("London UK") |>
    add_osm_feature (key = "name", value = "Thames", exact = FALSE) |>
    osmdata_sf ()
# Get ids of lines called "The Thames":
id <- rownames (dat$osm_lines [which (dat$osm_lines$name == "The Thames"), ])
# and find all multilinestring objects which include those lines:
osm_multilines (dat, id)
# Now note that
nrow (dat$osm_multilines) # = 24 multiline objects
nrow (osm_multilines (dat, id)) # = 1 - the recursive search selects the
# single multiline containing "The Thames"
}

Run the code above in your browser using DataLab