Skip to contents

Imports OpenStreetMap (OSM) data into R as 'sf', 'SC', 'sp', 'data.frame' or 'xml_document' objects. OSM data are extracted from the overpass API and processed with very fast C++ routines for return to R. The package enables simple overpass queries to be constructed without the user necessarily understanding the syntax of the overpass query language, while retaining the ability to handle arbitrarily complex queries. Functions are also provided to enable recursive searching between different kinds of OSM data (for example, to find all lines which intersect a given point).

Functions to Prepare Queries

Functions to Get Additional OSM Information

Functions to Extract OSM Data

Functions to Search Data

Author

Joan Maspons, Mark Padgham, Bob Rudis, Robin Lovelace, Maëlle Salmon