Learn R Programming

osmdata (version 0.3.0)

osmdata_sc: Return an OSM Overpass query as an osmdata_sc object in silicate (SC) format.

Description

Return an OSM Overpass query as an osmdata_sc object in silicate (SC) format.

Usage

osmdata_sc(q, doc, quiet = TRUE)

Value

An object of class osmdata_sc representing the original OSM hierarchy of nodes, ways, and relations.

Arguments

q

An object of class overpass_query constructed with opq and add_osm_feature or a string with a valid query, such as "(node(39.4712701,-0.3841326,39.4713799,-0.3839475);); out;". 39.4712701,-0.3841326,39.4713799,-0.3839475 May be be omitted, in which case the osmdata object will not include the query. See examples below.

doc

If missing, doc is obtained by issuing the overpass query, q, otherwise either the name of a file from which to read data, or an object of class xml2 returned from osmdata_xml.

quiet

suppress status messages.

See Also

Other extract: osmdata_data_frame(), osmdata_sf(), osmdata_sp(), osmdata_xml()

Examples

Run this code
if (FALSE) {
query <- opq ("hampi india") |>
    add_osm_feature (key = "historic", value = "ruins")
# Then extract data from 'Overpass' API
hampi_sc <- osmdata_sc (query)
}

# Complex query as a string (not possible with regular osmdata functions)
q <- '[out:xml][timeout:50];
    area[name="Països Catalans"][boundary=political]->.boundaryarea;

    rel(area.boundaryarea)[admin_level=8][boundary=administrative];
    map_to_area -> .all_level_8_areas;

    ( nwr(area.boundaryarea)[amenity=townhall]; >; );
    is_in;
    area._[admin_level=8][boundary=administrative] -> .level_8_areas_with_townhall;

    (.all_level_8_areas; - .level_8_areas_with_townhall;);
    rel(pivot);
    (._; >;);
    out;'

if (FALSE) {
no_townhall <- osmdata_sc (q)
no_townhall
}

Run the code above in your browser using DataLab