powered by
Retrieve status of the Overpass API
overpass_status(quiet = FALSE)
an invisible list of whether the API is available along with the text of the message from Overpass and the timestamp of the next available slot
if FALSE display a status message
FALSE
Other queries: add_osm_feature(), add_osm_features(), bbox_to_string(), getbb(), opq(), opq_around(), opq_csv(), opq_enclosing(), opq_osm_id(), opq_string()
add_osm_feature()
add_osm_features()
bbox_to_string()
getbb()
opq()
opq_around()
opq_csv()
opq_enclosing()
opq_osm_id()
opq_string()
if (FALSE) { overpass_status () }
Run the code above in your browser using DataLab