Learn R Programming

osmdata (version 0.4.1)

osmdata: osmdata class def

Description

osmdata class def

Usage

osmdata(
  bbox = NULL,
  overpass_call = NULL,
  meta = NULL,
  osm_points = NULL,
  osm_lines = NULL,
  osm_polygons = NULL,
  osm_multilines = NULL,
  osm_multipolygons = NULL
)

Arguments

bbox

bounding box

overpass_call

overpass_call

meta

metadata of overpass query, including timestamps and version numbers

osm_points

OSM nodes as sf Simple Features Collection of points or sp SpatialPointsDataFrame

osm_lines

OSM ways sf Simple Features Collection of linestrings or sp SpatialLinesDataFrame

osm_polygons

OSM ways as sf Simple Features Collection of polygons or sp SpatialPolygonsDataFrame

osm_multilines

OSM relations as sf Simple Features Collection of multilinestrings or sp SpatialLinesDataFrame

osm_multipolygons

OSM relations as sf Simple Features Collection of multipolygons or sp SpatialPolygonsDataFrame

Examples

Run this code
# This function should not need to be called directly!
osmdata ()

Run the code above in your browser using DataLab