powered by
osmdata class def
osmdata( bbox = NULL, overpass_call = NULL, meta = NULL, osm_points = NULL, osm_lines = NULL, osm_polygons = NULL, osm_multilines = NULL, osm_multipolygons = NULL )
bounding box
overpass_call
metadata of overpass query, including timestamps and version numbers
OSM nodes as sf Simple Features Collection of points or sp SpatialPointsDataFrame
OSM ways sf Simple Features Collection of linestrings or sp SpatialLinesDataFrame
OSM ways as sf Simple Features Collection of polygons or sp SpatialPolygonsDataFrame
OSM relations as sf Simple Features Collection of multilinestrings or sp SpatialLinesDataFrame
OSM relations as sf Simple Features Collection of multipolygons or sp SpatialPolygonsDataFrame
# This function should not need to be called directly! osmdata ()
Run the code above in your browser using DataLab